@@ -311,8 +311,10 @@ def create_manager_scripts(protocol_triad, cache_dir, task_folders, partition,
     # lists. Ex: 6 jobs in 4 processors = [2,2,1,1]
     tasks_per_node_list = distribute_items_in_fixed_length_list(
         requested_nodes, 
-        len(taskid_list)
+        len(taskid_list),
+        min_in_list = min_stack_per_core*cpus_per_node
     )
+    requested_nodes = len(tasks_per_node_list)  # Modifies input!
     
     if mem:
         turnon_mem = ""
@@ -324,24 +326,43 @@ def create_manager_scripts(protocol_triad, cache_dir, task_folders, partition,
     else:
         turnon_mempercpu = "#"
 
+
+    """
     # Reassess the number of requested nodes for avoiding asking
     #  for too many nodes. For requiring another node, all cpus of all
     #  nodes must have at least 10 tasks assigned to them
     #  WARNING: this does not keep into account the length of a task!
     if protocol != 'local' and min(tasks_per_node_list) < min_stack_per_core*cpus_per_node:
         grand = min_stack_per_core*cpus_per_node / max(tasks_per_node_list)
+        print("grand", grand)
         rqn = (
             int(requested_nodes / grand)
             + max(tasks_per_node_list) - min(tasks_per_node_list)
         )
+        print("rqn", rqn)
         requested_nodes = max(1, rqn)
+        print("requested_nodes", requested_nodes)
         tasks_per_node_list = distribute_items_in_fixed_length_list(
             requested_nodes, 
             len(taskid_list)
         )
+        print("new tasks_per_node_list", tasks_per_node_list)
+
+    tasks_per_node_list = [x for x in tasks_per_node_list if x > 0]
+    if len(tasks_per_node_list) < cpus_per_node:
+        print("too many processors have been requested")
+        if protocol != 'local':
+            print("node exclusiveness will be turned off")
+            turnon_exclusiveness = "#"
+        cpus_per_node = len(tasks_per_node_list)
+    """
+
+
     print("Protocol used:", protocol)
+    print("Total number of tasks:", len(taskid_list))
     print("Actual number of nodes used:", requested_nodes)
     print("Each with {0} cpus".format(cpus_per_node))
+    print("tasks_per_node_list", tasks_per_node_list)
 
     # Each manager script handles one node
     #  The manager reads a file of adresses where it will find the clean
@@ -438,6 +459,11 @@ def create_manager_scripts(protocol_triad, cache_dir, task_folders, partition,
     with open(fs_locations["build_exec"] + 'periodic_check.sh', 'w') as cmf:
         cmf.write("\n".join(manager_cmd))
     subprocess.call(["chmod", "777", fs_locations["build_exec"] + 'periodic_check.sh'])
+    with open(fs_locations["build_exec"] + 'submit.sh', 'w') as sf:
+        for job_id, task_list in tasks_per_job:
+            sf.write("sbatch {0}/outer_manager_{1}{2}.slurm\n".format(fs_locations["runtime_exec"],
+                batch_job_code, str(job_id).zfill(3)))
+    subprocess.call(["chmod", "777", fs_locations["build_exec"] + 'submit.sh'])
 
     if protocol == 'remote':
         cpall_cmd = ["bash", data_transfer_protocol, fs_locations["build_root"], "{0}:{1}".format(remote_machine, fs_locations["runtime_root"])]
@@ -467,23 +493,21 @@ def remote_job_control(protocol_triad, batch_job_code, fs_locations, tasks_per_j
 
     if not only_gather:
         if protocol != 'local':
-            for job_id, task_list in tasks_per_job:
-                chk_cmd = [
-                    "ssh",
-                    remote_machine,
-                    "sleep 60;",
-                    "sbatch",
-                    fs_locations["runtime_exec"] + 'outer_manager_{0}{1}.slurm' \
-                        .format(batch_job_code, str(job_id).zfill(3))
-                ]
-                if DEBUG:
-                    print("COMMAND", " ".join(chk_cmd))
-                    p = subprocess.Popen(chk_cmd)
-                else:
-                    p = subprocess.Popen(chk_cmd,
-                        stderr=devnull,
-                        stdout=devnull
-                    )
+            chk_cmd = [
+                "ssh",
+                remote_machine,
+                "sleep 60;",
+                "bash",
+                fs_locations["runtime_exec"] + 'submit.sh'
+            ]
+            if DEBUG:
+                print("COMMAND", " ".join(chk_cmd))
+                p = subprocess.Popen(chk_cmd)
+            else:
+                p = subprocess.Popen(chk_cmd,
+                    stderr=devnull,
+                    stdout=devnull
+                )
         else:
             # If no hpc, there is only one node, i.e. one manager
             mname = 'outer_manager_{0}{1}.slurm'.format(batch_job_code, str(0).zfill(3))
